/v1/projects/{project_id}/iou/vms — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Iou »

# /v1/projects/{project_id}/iou/vms

Contents

- /v1/projects/{project_id}/iou/vms
  - POST /v1/projects/{project_id}/iou/vms
    - Parameters
    - Response status codes
    - Input
    - Output
    - Sample session

## POST /v1/projects/{project_id}/iou/vms

Create a new IOU instance

### Parameters

- project_id: UUID for the project

### Response status codes

- 400: Invalid request
- 201: Instance created
- 409: Conflict

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
console |  | ['integer', 'null'] | console TCP port
ethernet_adapters |  | integer | How many ethernet adapters are connected to the IOU
initial_config_content |  | ['string', 'null'] | Initial configuration of the IOU
l1_keepalives |  | ['boolean', 'null'] | Always up ethernet interface
name | ✔ | string | IOU VM name
nvram |  | ['integer', 'null'] | Allocated NVRAM KB
path | ✔ | string | Path of iou binary
ram |  | ['integer', 'null'] | Allocated RAM MB
serial_adapters |  | integer | How many serial adapters are connected to the IOU
vm_id |  |  | IOU VM identifier

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
console | ✔ | integer | console TCP port
ethernet_adapters | ✔ | integer | How many ethernet adapters are connected to the IOU
initial_config | ✔ | ['string', 'null'] | Path of the initial config content relative to project directory
l1_keepalives | ✔ | boolean | Always up ethernet interface
name | ✔ | string | IOU VM name
nvram | ✔ | integer | Allocated NVRAM KB
path | ✔ | string | Path of iou binary
project_id | ✔ | string | Project UUID
ram | ✔ | integer | Allocated RAM MB
serial_adapters | ✔ | integer | How many serial adapters are connected to the IOU
vm_id | ✔ | string | IOU VM UUID

### Sample session

    curl -i -X POST 'http://localhost:8000/projects/{project_id}/iou/vms' -d '{"ethernet_adapters": 0, "initial_config_content": "hostname test", "l1_keepalives": true, "name": "PC TEST 1", "nvram": 512, "path": "/private/var/folders/3s/r2wbv07n7wg4vrsn874lmxxh0000gn/T/pytest-3621/test_iou_create_with_params0/iou.bin", "ram": 1024, "serial_adapters": 4}'

    POST /projects/{project_id}/iou/vms HTTP/1.1
    {
        "ethernet_adapters": 0,
        "initial_config_content": "hostname test",
        "l1_keepalives": true,
        "name": "PC TEST 1",
        "nvram": 512,
        "path": "/private/var/folders/3s/r2wbv07n7wg4vrsn874lmxxh0000gn/T/pytest-3621/test_iou_create_with_params0/iou.bin",
        "ram": 1024,
        "serial_adapters": 4
    }

    HTTP/1.1 201
    CONNECTION: keep-alive
    CONTENT-LENGTH: 440
    CONTENT-TYPE: application/json
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 GNS3/1.3.dev1
    X-ROUTE: /v1/projects/{project_id}/iou/vms

    {
        "console": 2000,
        "ethernet_adapters": 0,
        "initial_config": "initial-config.cfg",
        "l1_keepalives": true,
        "name": "PC TEST 1",
        "nvram": 512,
        "path": "/private/var/folders/3s/r2wbv07n7wg4vrsn874lmxxh0000gn/T/pytest-3621/test_iou_create_with_params0/iou.bin",
        "project_id": "a1e920ca-338a-4e9f-b363-aa607b09dd80",
        "ram": 1024,
        "serial_adapters": 4,
        "vm_id": "20e66cd4-52ef-4ad2-a44e-16bce06fd6f2"
    }

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Iou »